/*
  license GPL v3 ...........

  description of this file:
  a page for viewing a user selected RSS feed ;

  Architecture:
  page
  {
    ToolbarActions

    Rectangle
    {
        label(RSS feed title)
    }

    ListView
    {
    }

    Component(delegate)

    XmlListModel(rss feed)
  }
*/

import QtQuick 2.0
import QtQuick.XmlListModel 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem

Page {
    id: page_feed

    property string rssmodel_url: ""
    property string rsstitle: ""
    property int rssIndex: 0
    property variant rss_model

    onRssIndexChanged:
    {
        rss_listview.currentIndex = rssIndex
        rss_listview.positionViewAtIndex(rss_listview.currentIndex, ListView.Center)
    }

    function setFeed(model, index)
    {
        console.log("Input index: ", index)
        rss_model = model
        rssIndex = index
    }

    function reloadPageContent() {

    }

    tools: ToolbarItems {
        id: toolbar

        ToolbarButton {
            action: Action {
                text:  i18n.tr("index 0")
                iconSource: Qt.resolvedUrl("avatar.png")
                onTriggered:
                {
                    rss_listview.currentIndex = 10
                }
            }
        }

        ToolbarButton {
            action: Action {
                text:  i18n.tr("index 1")
                iconSource: Qt.resolvedUrl("avatar.png")
                onTriggered:
                {
                    rss_listview.currentIndex = 20
                }
            }
        }

        ToolbarButton {
            action: Action {
                text:  i18n.tr("Open site")
                iconSource: Qt.resolvedUrl("avatar.png")
                onTriggered:
                {
                    console.log("Open site", rss_listview.model.get(rss_listview.currentIndex).link)
                    Qt.openUrlExternally(rss_listview.model.get(rss_listview.currentIndex).link)
                }
            }
        }
    }

    //////////////////////////////////////////////      shows the RSS feed title
    Rectangle
    {
        id: rec_title
        width: parent.width
        height: label_title.height + units.gu(1)
        color: "orange"

        Label
        {
            id: label_title
            anchors.centerIn: parent
            width: parent.width - units.gu(2)
//            ItemStyle.class: "title"
            wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            text: rsstitle
            fontSize: "large"
            color: "white"
        }
    }

    //////////////////////////////////////////////      a listview to show the RSS content
    ListView
    {
        id: rss_listview
        width: parent.width
        anchors.bottom: parent.bottom
        // anchors.bottomMargin: units.gu(1)
        anchors.top: rec_title.bottom
        anchors.topMargin: units.gu(2)
        snapMode: ListView.SnapOneItem
        cacheBuffer: 90
        boundsBehavior: Flickable.StopAtBounds
        orientation: ListView.Horizontal
        contentHeight: parent.width * count
        model: rss_model
        delegate: xmldelegate
        highlightFollowsCurrentItem: true
        highlightRangeMode: ListView.StrictlyEnforceRange

        onCurrentIndexChanged:
        {
            console.log("ListView onCurrentIndexChanged", currentIndex)
            rsstitle = rss_listview.model.get(currentIndex).feed_name
        }
    }

    //////////////////////////////////////////////      delegate for ListView
    Component
    {
        id: xmldelegate

        Flickable {
            id: scrollArea

            clip: true

            width: rss_listview.width
            height: rss_listview.height

            contentWidth: width
            contentHeight: innerAreaColumn.height

            Column {
                id: innerAreaColumn

                spacing: units.gu(2)
                width: parent.width

                Label {
                    fontSize: "large"
                    text: title
                    anchors.horizontalCenter: parent.horizontalCenter
                    width: parent.width - units.gu(4)
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                    color: "black"
                }

                Label {
                    text: description
                    anchors.horizontalCenter: parent.horizontalCenter
                    width: parent.width - units.gu(4)
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                    color: "black"
                    clip: true

                    MouseArea
                    {
                        anchors.fill: parent
                        onClicked:
                        {
                            console.log("current index : " + index) ;
                        }
                    }
                }
            }

        }

    }
}
