import QtQuick 2.0
import QtQuick.XmlListModel 2.0

import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItems
import Ubuntu.Components.Popups 0.1

import "databasemodule_v2.js" as DB

Item {
    id: xmlnetwork

    property variant feedList: []               // feed list from database
    property variant currentFeed                // current downloading feed

    signal downloadFinish()

    function addFeedList(feedarray)             // a feed list ready for download
    {
        feedList = feedarray ;
        downloadFeed();
    }

    function downloadFeed()                     // download one feed
    {
        var oneFeed ;
        var feedarray = [] ;
        feedarray = feedList ;
        if (feedarray.length == 0)
        {
            downloadFinish()
            return ;
        }
        oneFeed = feedarray.shift() ;
        console.log(JSON.stringify(oneFeed));
        feedList = feedarray ;
        currentFeed = oneFeed ;
        thinXmlHttpRequestWraper.loadXml(oneFeed.source) ;
    }

    /* Thin wrapper around XMLHttpRequest.
     * 0 stage. Loading raw XML data from network.
     */
    QtObject {
        id: thinXmlHttpRequestWraper

        signal xmlLoaded(string xml)
        signal xmlfailed(string xmlUrl)

        function loadXml(xmlUrl) {
            if (xmlUrl.indexOf('http://') == -1)
                xmlUrl = 'http://' + xmlUrl;
            var doc = new XMLHttpRequest();
            doc.onreadystatechange = function() {
                if (doc.readyState == XMLHttpRequest.DONE) {
                    if (doc.status == 200 ) {
                        xmlLoaded(doc.responseText)
                    } else {
                        console.log("XMLHttpRequest ERROR", doc.status, doc.statusText)
//                        feedList.loadFailed(xmlUrl) // mb need to replace with signal, as in xmllistmodel.
                        xmlfailed(xmlUrl);
                    }
                }
            }

            doc.open("GET", xmlUrl);
            doc.send();
        }

        onXmlLoaded: {
//            feedInfo.xml = xml
            feedInfo.startFeedParsing(xml) ;
            // Another functions, such as saving in database and so on.
        }
    } // QtObject

    /* First stage - need to gain information about feed from XML
     * and save it to database. Next step - loading entries.
     */
    XmlListModel {
        id: feedInfo

        //property string currentUrl: "" // TODO Move to another place later.
        //property int feed_id           // id from database

        // signal infoLoaded(string url, string title, string siteLink, string description)
        signal infoLoaded(string url, var data)
        signal loadFailed(string url)

        query: "/rss/channel"

        function startFeedParsing(xml)
        {
            feedInfo.xml = xml ;
        }

        XmlRole { name: "title"; query: "title/string()" }
        XmlRole { name: "link"; query: "link/string()" }
        XmlRole { name: "description"; query: "description/string()" }
        XmlRole { name: "pubDate"; query: "pubDate/string()" }
        XmlRole { name: "image"; query: "image/string()" }

        onStatusChanged: {
            console.log("feedInfo onStatusChanged") ;
            var firstItem
            switch(status)
            {
            case XmlListModel.Error:
                console.log("XmlListModel", "ERROR", errorString())
                loadFailed(source)
                break
            case XmlListModel.Ready:
                console.log("XmlListModel", "READY", "COUNT", count)
                if (count === 1) {
                    firstItem = feedInfo.get(0)
                    infoLoaded(currentFeed.source, firstItem)

                    // update feed info to database
                    DB.updateFeedByXml(currentFeed.id, firstItem.link, firstItem.description, firstItem.title, firstItem.pubDate) ;

                    articleInfo.startEntriesParsing(currentFeed.source /*currentUrl*/, xml)
                    DB.clearArticles(currentFeed.id)
                    //currentUrl = "" // TODO mb no need
                } else { // if (count === 0 ) {
                    loadFailed("currentUrl")
                }
                break
            case XmlListModel.Loading:
                console.log("XmlListModel", "LOADING")
                break
            case XmlListModel.Null:
                console.log("XmlListModel", "NULL")
                break
            }
        }
    } // XmlListModel

    /* Second stage - need to parse XML and get all items from it.
     * These items will be store into database
     *
     * Very useful http://www.w3schools.com/xpath/xpath_functions.asp
     */
    XmlListModel {
        id: articleInfo

        property string curUrl: ""

        function startEntriesParsing(url, strXml) {
            articleInfo.curUrl = url
            articleInfo.xml = strXml
        }

        query: "/rss/channel/item"

        XmlRole { name: "title"; query: "title/string()" }
        XmlRole { name: "link"; query: "link/string()" }
        XmlRole { name: "guid"; query: "guid/string()" }
        XmlRole { name: "pubDate"; query: "pubDate/string()" }
        XmlRole { name: "description"; query: "description/string()" }
        XmlRole { name: "content"; query: "*[name()='content:encoded']/string()" }

        onStatusChanged: {
            console.log("articleInfo onStatusChanged") ;
            var article
            switch(status)
            {
            case XmlListModel.Error:
                console.log("articleInfo", "ERROR", errorString())
                break
            case XmlListModel.Ready:

                console.log("articleInfo", "READY", "COUNT", count)
//                for (var i = 0; i < count; i++) {

//                    article = articleInfo.get(i)
//                    var title =  article.title == undefined ? "" : article.title
//                    var guid =  article.guid == undefined ? Qt.md5(title) : article.guid
//                    var link =  article.link == undefined ? "" : article.link
//                    var pubDate =  article.pubDate == undefined ? "" : article.pubDate
//                    var description =  article.description == undefined ? "" : article.description
//                    var content =  article.content == undefined ? "" : article.content
//                    DB.addArticle(title, link, description, pubDate, guid, currentFeed.id) ;

//                }
                DB.addArticles(articleInfo, currentFeed.id);
                //feedsReloaded()

                downloadFeed();
                break
            case XmlListModel.Loading:
                console.log("articleInfo", "LOADING")
                break
            case XmlListModel.Null:
                console.log("articleInfo", "NULL")
                break
            }
        }
    } // XmlListModel
}
