/*
 * Copyright 2013 Canonical Ltd.
 *
 * This file is part of ubuntu-rssreader-app.
 *
 * ubuntu-calculator-app is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * ubuntu-calculator-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

.pragma library

var SECONDS_LIMIT = 60 * 1000;
var MINUTES_LIMIT = 60 * SECONDS_LIMIT;
var HOURS_LIMIT = 24 * MINUTES_LIMIT;
var DAYS_LIMIT = 30 * HOURS_LIMIT;

// TODO: handle i18n
var FORMAT_LIMITS = [
            { "limit": SECONDS_LIMIT, "formats": ["%0 second ago", "%0 seconds ago"] },
            { "limit": MINUTES_LIMIT, "formats": ["%0 minute ago", "%0 minutes ago"] },
            { "limit": HOURS_LIMIT,   "formats": ["%0 hour ago", "%0 hours ago"] },
            { "limit": DAYS_LIMIT,    "formats": ["%0 day ago", "%0 days ago"] },
]

// fallback if none of the above formats matched
// TODO: handle i18n
var DEFAULT_DATE_FORMAT = "MMM Do"

function parseDate(dateAsStr) {
    return Date.parse(dateAsStr);
}

function formatPostTime(dateAsStr, i18n) {
    var now = new Date();
    var then = parseDate(dateAsStr);
    var diff = now - then;
    var formattedDiff = formatDiff(diff, then, i18n);
    console.log("DDD DIFF", diff, formattedDiff)
    return formattedDiff;
}

function formatDiff(diff, then, i18n) {
    for (var i=0; i<FORMAT_LIMITS.length; ++i) {
        var limit = FORMAT_LIMITS[i].limit;
        if (diff < limit) {
            // use previous limit to calculate number of current units
            // e.g. to calculate hours divide by MINUTES_LIMIT
            // (because MINUTES_LIMIT is 1 hours) etc.
            var val = Math.floor(diff / (i > 1 ? FORMAT_LIMITS[i-1].limit : SECONDS_LIMIT))
            return i18n.tr(FORMAT_LIMITS[i].formats[0], FORMAT_LIMITS[i].formats[1], val).arg(val)
        }
    }
    return then.toString(i18n.tr(DEFAULT_DATE_FORMAT))
}
