import QtQuick 2.0
import QtQuick.XmlListModel 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.Components.Popups 0.1
import "./feeds"

import "./databasemodule_v2.js" as DB

MainView {
    // objectName for functional testing purposes (autopilot-qt5)
    id: mainView
    objectName: "mainView"
    applicationName: "RSS reader"

    width: units.gu(50)
    height: units.gu(75)

    headerColor: "#583437"
    backgroundColor: "#624251"
    footerColor: "#65445a"

    Component.onCompleted:
    {
        //////////////////////////////////////////////////////////////  below DB operation is for avoid empty db
        // DB.dropTable()
        var feeds = DB.loadFeeds();

        if (feeds.rows.length < 1)
        {
            DB.addFeed("" , "http://news.yahoo.com/rss/topstories");
            DB.addFeed("" , "http://news.yahoo.com/rss/tech");
            DB.addFeed("" , "http://www.engadget.com/rss.xml");
            DB.addFeed("" , "http://qtrosapps.hostenko.com/feed/")
            DB.addTag("news");
            DB.addTag("tech");
            DB.addTag("engadget");
            DB.addFeedTag(1, 1) ;
            DB.addFeedTag(2, 2) ;
            DB.addFeedTag(3, 3) ;
            refresh() ;
        }

        //else repeater.reloadTabs() ;     // load tabs from db
    }

    function refresh()             //  download all articles
    {
        var feeds = DB.loadFeeds();
        console.log(JSON.stringify(feeds));
        console.log(JSON.stringify(feeds.rows.item(0)));
        var feedarray = [] ;
        for (var i=0; i< feeds.rows.length; i++)
        {
            //            console.log(JSON.stringify(feeds.rows.item(i)));
            feedarray.push(feeds.rows.item(i));
        }
        //        console.log(JSON.stringify(feedarray));
        xmlnetwork.addFeedList(feedarray);
    }

    function toRssPage(model, index)     //   go to single article page     // bugs remain
    {
        feed_page.setFeed(model, index)
        pageStack.push(feed_page)
    }

    PageStack {
        id: pageStack
        anchors.fill: parent

        Component.onCompleted:
        {
            push(tabs);                      // use tabs as first page
            // push(editFeedsPage);
        }

        onCurrentPageChanged: {
            console.log("onCurrentPageChanged", currentPage.title)
            currentPage.reloadPageContent()
        }

        Page {
            id: tabs
            visible: false
            title: i18n.tr("Shorts")
            // anchors.margins: units.gu(4)

            function reloadPageContent() {

            }

            tools: ToolbarItems {
                id: toolbar

                back: ToolbarButton {
                    action: Action {
                        text:  i18n.tr("Refresh")
                        iconSource: Qt.resolvedUrl("./icons_tmp/reload.svg")
                        onTriggered:
                        {
                            refresh();
                            toolbar.opened = false;
                        }
                    }
                }

                ToolbarButton {
                    action: Action {
                        text:  i18n.tr("List view")
                        iconSource: Qt.resolvedUrl("./icons_tmp/view-fullscreen.svg")
                        onTriggered: {
                            console.log("NOT IMPLEMENTED")
                        }
                    }
                }

                ToolbarButton {
                    id: addReadsBtn
                    action: Action {
                        text:  i18n.tr("Add reads")
                        iconSource: Qt.resolvedUrl("./icons_tmp/add.svg")
                        onTriggered: {
                            // pageStack.push(editFeedsPage)
                            PopupUtils.open(addReadsPopoverComp, addReadsBtn)
                        }
                    }
                }

                ToolbarButton {
                    action: Action {
                        text:  i18n.tr("Edit topics")
                        iconSource: Qt.resolvedUrl("./icons_tmp/edit.svg")
                        onTriggered: {
                            pageStack.push(editFeedsPage)
                        }
                    }
                }
            }

            Component.onCompleted: shorts_view.reload() ;

            ListColumnView
            {
                id: shorts_view
                anchors.margins: units.gu(2)
                isAll: true
            }

            Component {
                id: addReadsPopoverComp

                ActionSelectionPopover {
                    id: addReadsPopover

                    actions: ActionList {
                        id: popoverActionsList

                        Action {
                            text: i18n.tr("+ Add feeds")
                            onTriggered: {
                                /* When we want to show "Append feed" page from
                                 * any page except of "Choose topic",
                                 * we should clear it (mark as dirty).
                                 */
                                pageStack.push(appendFeedPage, {"isDirty" : true})
                            }
                        }

                        Action {
                            text: i18n.tr("+ New topic")
                            onTriggered: {
                                pageStack.push(createTopicPage)
                            }
                        }

                        Action {
                            text: i18n.tr("Add online accounts")
                            onTriggered: {
                                console.log("NOT IMPLEMENTED")
                            }
                        }

                        Action {
                            text: i18n.tr("Import subscriptions")
                            onTriggered: {
                                console.log("NOT IMPLEMENTED")
                            }
                        }
                    } // ActionList
                }
            }
        }


        // ************************************************************* ////////////////////////////////////


        ManageFeedsPage {
            id: editFeedsPage
            visible: false
            flickable: null
        } // Page

        // ************************************************************* ////////////////////////////////////

        CreateTopicPage {
            id: createTopicPage
            visible: false
            flickable: null
        } // Page

        ManageTopicsPage {
            id: manageTopicsPage
            flickable: null
            visible: false
        } // Page "Topics"


        // ******************************** APPEND FEED ***********************///////////////

        AppendFeedPage {
            id: appendFeedPage

            title: "Append feed"
            flickable: null
            visible: false
        }


        // ************************ Choose Topic PAGE ******************////////////

        ChooseTopicPage {
            id: chooseTopicPage
        }

        // independent page for viewing one RSS feed
        RssFeedPage
        {
            id: feed_page
            visible: false
        }
    }

    XmlNetwork         //  all download and xml parse functions here
    {
        id: xmlnetwork

        onDownloadFinish:
        {
            //            griddemo.reload();
            shorts_view.reload() ;
            // repeater.reloadTabs() ;
        }
    }
}
